@@ -1,14 +1,18 @@
-__author__ = 'coty'
 """
     This file contains all the logic necessary to execute the unit test code based on the parameters passed by the user.
 """
+__author__ = 'coty'
+
 
 import logging
 
-from utilities.settings import etltest_config, console
+from .utilities.settings import etltest_config, console
 
 
 class CodeExecutor():
+    """
+    The Code Executor runs the unittest code created and passes results back to the user.
+    """
 
     def __init__(self, out_dir):
         """
@@ -49,5 +53,5 @@ class CodeExecutor():
                 return 0
             else:
                 self.log.info(file_path)
-                print subprocess.check_output([sys.executable, file_path])
+                print(subprocess.check_output([sys.executable, file_path]))
 
