@@ -1,7 +1,8 @@
-s__author__ = 'coty, ameadows'
 """
     This file contains all the logic to connect to data sources using SQLAlchemy.
 """
+__author__ = 'coty, ameadows'
+
 
 import logging
 import sys
@@ -14,6 +15,9 @@ from etltest.utilities.yaml_parser import YAMLParser
 
 
 class DataConnector():
+    """
+    The DataConnector module is the location to handle data access and manipulation to and from a data source/target.
+    """
     #TODO:  Need to determine if a data validation tool is required.  For instance, does record set match the table
     # structure?
     def __init__(self, conn_name):
@@ -132,7 +136,7 @@ class DataConnector():
         else:
             result = self.session.query(table).filter(where_stmt)
 
-        self.log.debug(u"Executing query {0:s}".format(result))
+        self.log.debug("Executing query {0:s}".format(result))
 
         return self.to_json(result, table)
 
@@ -158,7 +162,7 @@ class DataConnector():
         else:
             set = []
             for item in full_set:
-                for key in item.keys():
+                for key in list(item.keys()):
                     set.append(item[key])
             return set
 
@@ -174,7 +178,7 @@ class DataConnector():
         results = [] # In the event nothing is in the set, return empty set.
         col_types = dict()
         for result in result_set:
-            self.log.debug(u"Processing record: {0:s}".format(result))
+            self.log.debug("Processing record: {0:s}".format(result))
             table_json = {}
             i = 0
             for column in table._columns:
