@@ -1,3 +1,7 @@
+"""
+This is the main class for etlTest.  All other code is kicked off from here.
+"""
+
 #!/usr/bin/python
 __author__ = 'coty, ameadows'
 
@@ -16,23 +20,23 @@ def create_parser():
     """
     parser = argparse.ArgumentParser(
         description='Automated data integration test generator and executor.',
-        epilog='etlTest -d /your/test_file/directory/ -g'
+        epilog='etlTest -d /your/test_file/directory/ -g unit'
     )
 
     parser.add_argument('-f', '--infile', nargs='?', type=str, dest='in_file', help='Specify the input file')
     parser.add_argument('-d', '--indir', nargs='?', type=str, dest='in_dir', help='Specify the input directory')
     parser.add_argument('-o', '--outdir', nargs='?', type=str, dest='out_dir', help='Specify the output directory')
-    parser.add_argument('-g', '--gen', dest='gen_code', default=False, action='store_true',
-                        help='Generate new test code')
+    parser.add_argument('-g', '--gen', nargs='?', type=str, choices=['all', 'unit', 'suite'], dest='gen_code',
+                        default='all', help='Generate new test code')
     parser.add_argument('-e', '--exec', dest='exec_code', default=False, action='store_true',
                         help='Execute test code')
     parser.add_argument('-t', '--test', dest='test_run', default=False, action='store_true',
                         help='Run app as tests.  Does not persist the generated or executed code.')
-    parser.add_argument('-v', '--version', action='version', version='%(prog)s 1.1')
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.1.5 - Beta')
 
-    # subparsers = parser.add_subparsers(title="Reference Data Handler",
-    #                                    help="Import and synchronize reference data sets",
-    #                                    dest="reference_handler")
+    # subparsers = parser.add_subparsers(title="Sub Processes",
+    #                                    description="Sub-processes for etlTest",
+    #                                    dest='subparser_name')
     # subparsers.required = False
 
     return parser
@@ -84,12 +88,13 @@ def main():
 
     if 'ref' in extra:
         # We require a source connection to work with.
-        if ref_args.source is None:
-            parser_ref.error("A source is required to work with reference data.  Please provide an existing data source.")
+        if args.source is None:
+            parser.error("A source is required to work with reference data.  "
+                         "Please provide an existing data source.")
 
         # We also need a table name to pull data from.
         if ref_args.table is None:
-            parser_ref.error("A source table is required to work with reference data.  "
+            parser.error("A source table is required to work with reference data.  "
                          "Please provide an existing reference table.")
 
         # It's okay if a column is not specified for identifying the records.  We'll number them.
@@ -103,7 +108,9 @@ def main():
 
             # Now we need to process the data and turn it into a YAML file.
 
-            print(u"Generating YAML file {0:s}/{1:s}.yml using {2:s} as the record identifier.".format(ref_args.source, ref_args.table, ref_args.column))
+            print(u"Generating YAML file {0:s}/{1:s}.yml using {2:s} as the record identifier.".format(ref_args.source,
+                                                                                                       ref_args.table,
+                                                                                                       ref_args.column))
             YAMLParser().write_file(data_set, ref_args.source, ref_args.table, ref_args.column)
 
         if ref_args.refresh_data == 'ours':
@@ -133,11 +140,11 @@ def main():
 
             if args.in_file:
                 print(u"Attempting to process: {0:s}".format(args.in_file))
-                CodeGenerator(in_file=args.in_file, out_dir=out_dir).generate_test()
+                CodeGenerator(in_file=args.in_file, out_dir=out_dir).generate_tests(args.gen_code)
 
             if args.in_dir:
                 print(u"Attempting to process: {0:s}".format(args.in_dir))
-                CodeGenerator(in_dir=args.in_dir, out_dir=out_dir).generate_test()
+                CodeGenerator(in_dir=args.in_dir, out_dir=out_dir).generate_tests(args.gen_code)
 
             # TODO: Decide if there should be a way to check if generated code should be updated or not.
             # TODO: Fully enable test run capability.
