@@ -1,15 +1,21 @@
-__author__ = 'ameadows'
 """
     This file contains all the logic necessary to execute ETL code based on the settings stored in the tools settings
     file.  Process execution should occur after the test data is loaded and before the unit tests are run.
 """
+__author__ = 'ameadows'
+
 import logging
 import os
+
 import paramiko
+
 from etltest.utilities.settings_manager import SettingsManager
 
-class ProcessExecutor():
 
+class ProcessExecutor():
+    """
+    ProcessExecutor takes the provided input from the etlTest main function and kicks off the given ETL process.
+    """
     def __init__(self, tool_name):
 
         """
@@ -25,7 +31,7 @@ class ProcessExecutor():
 
         self.tool_name = tool_name
         self.tool = SettingsManager().get_tool(tool_name)
-        self.log.info(u"Setting up tool {0:s}: {1:s}".format(tool_name, self.tool))
+        self.log.info("Setting up tool {0:s}: {1:s}".format(tool_name, self.tool))
 
         self.local_names = ['localhost', '127.0.0.1']
 
@@ -69,10 +75,16 @@ class ProcessExecutor():
         for line in stdout:
             self.log.info(line)
 
-
     def execute_process(self, process_type, process_name):
-
-        self.log.info(u"Attempting to run {0:s} with {1:s}".format(process_name, self.tool_name))
+        """
+        Takes the process type and name of the process and kicks it off.
+        :param process_type: The type of process to be executed based on the tool used.
+        :type process_type str
+        :param process_name: The name of the process to be executed.
+        :type process_name str
+        :return:
+        """
+        self.log.info("Attempting to run {0:s} with {1:s}".format(process_name, self.tool_name))
 
         from subprocess import call
 
@@ -80,16 +92,16 @@ class ProcessExecutor():
 
         process_param = self.tool['process_param']
         params = self.tool['params']
-        self.log.info(u"Using {0:s} with {1:s}".format(process_param, params))
+        self.log.info("Using {0:s} with {1:s}".format(process_param, params))
 
         process = process_param + process_name
-        self.log.info(u"Running {0:s}".format(process))
+        self.log.info("Running {0:s}".format(process))
 
         for type in self.tool['script_types']:
             if type['type'] == process_type:
                 tool_script = type['script']
 
-        self.log.info(u"Using {0:s} with {1:s}".format(tool_path, tool_script))
+        self.log.info("Using {0:s} with {1:s}".format(tool_path, tool_script))
 
         tool_path_script = os.path.join(tool_path, tool_script)
 
