@@ -1,3 +1,7 @@
+"""
+Testing the DataConnector module.
+"""
+
 __author__ = 'ameadows'
 
 import unittest
@@ -8,7 +12,10 @@ from etltest.utilities.settings_manager import SettingsManager
 
 
 class DataConnectorTests(unittest.TestCase):
-
+    """
+    We first make sure that the environment is set up by using the first_run_test method.  We then set some parameters
+    up to properly test for a given source and table.
+    """
     def setUp(self):
 
         SettingsManager().first_run_test()
@@ -21,36 +28,46 @@ class DataConnectorTests(unittest.TestCase):
         DataConnector(self.source).truncate_data(self.table)
 
     def test_bad_connection(self):
-        #Testing to see if a non existent connection will fail gracefully.
+        """
+        Testing to see if a non existent connection will fail gracefully.
+        """
         records = [1, 2]
 
-        with self.assertRaises(KeyError) as raises:
+        with self.assertRaises(KeyError):
             DataConnector("BadConnection").generate_data(self.table, records)
 
     def test_generate_data_all(self):
-        #Testing to see if the full data set is generated.
+        """
+        Testing to see if the full data set is generated.
+        """
         given_result = DataConnector(self.source).generate_data(self.table)
         expected_result = [{'first_name': 'Bob', 'last_name': 'Richards', 'user_id': 1, 'zipcode': 55555,
-                            'birthday': datetime.date(2000, 1, 4), 'is_active': 0}, {'first_name': 'Sarah',
-                            'last_name': 'Jenkins', 'user_id': 2, 'zipcode': 12345,
-                            'birthday': datetime.date(2000, 2, 2), 'is_active': 1},{'first_name': 'Frank',
-                            'last_name': 'Williams', 'user_id': 3, 'is_active': 0, 'zipcode': 56789,
-                            'birthday': datetime.date(1972, 3, 3)},{'first_name': None, 'last_name': 'Thomas',
+                            'birthday': datetime.date(2000, 1, 4), 'is_active': 0},
+                           {'first_name': 'Sarah', 'last_name': 'Jenkins', 'user_id': 2, 'zipcode': 12345,
+                            'birthday': datetime.date(2000, 2, 2), 'is_active': 1},
+                           {'first_name': 'Frank', 'last_name': 'Williams', 'user_id': 3, 'is_active': 0,
+                            'zipcode': 56789, 'birthday': datetime.date(1972, 3, 3)},
+                           {'first_name': 'Thomas', 'last_name': 'Stedding',
                             'user_id': 4, 'is_active': 1, 'zipcode': 44444, 'birthday': datetime.date(1923, 1, 4)}]
 
-        self.assertItemsEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
+
     def test_generate_data_subset(self):
-        #Testing to see if a subset of data is generated and not the full data set.
+        """
+        Testing to see if a subset of data is generated and not the full data set.
+        """
         given_result = DataConnector(self.source).generate_data(self.table, self.records)
         expected_result = [{'first_name': 'Bob', 'last_name': 'Richards', 'user_id': 1, 'zipcode': 55555,
-                            'birthday': datetime.date(2000, 1, 4), 'is_active': 0}, {'first_name': 'Sarah',
-                            'last_name': 'Jenkins', 'user_id': 2, 'zipcode': 12345,
+                            'birthday': datetime.date(2000, 1, 4), 'is_active': 0},
+                           {'first_name': 'Sarah', 'last_name': 'Jenkins', 'user_id': 2, 'zipcode': 12345,
                             'birthday': datetime.date(2000, 2, 2), 'is_active': 1}]
 
         self.assertEqual(given_result, expected_result)
 
     def test_generate_data_subset_non_existent_records(self):
-        # Testing to see if a record doesn't exist, the data generator will only return valid records.
+        """
+        Testing to see if a record doesn't exist, the data generator will only return valid records.
+        """
         records = [1, 2, 20]
         given_result = DataConnector(self.source).generate_data(self.table, records)
         expected_result = [{'first_name': 'Bob', 'last_name': 'Richards', 'user_id': 1, 'zipcode': 55555,
@@ -61,17 +78,21 @@ class DataConnectorTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_insert_data(self):
-        # Testing to see if the data set will be inserted correctly.
+        """
+        Testing to see if the data set will be inserted correctly.
+        """
         DataConnector(self.source).insert_data(self.table, self.records)
         given_result = DataConnector(self.source).select_data("all_columns", self.table, "user_id IN (1, 2)")
         expected_result = {'first_name': 'Bob', 'last_name': 'Richards', 'user_id': 1, 'zipcode': '55555'
                             , 'birthday': datetime.date(2000, 1, 4), 'is_active': 0}, {'first_name': 'Sarah', 'last_name': 'Jenkins'
                             , 'user_id': 2, 'zipcode': '12345', 'birthday': datetime.date(2000, 2, 2), 'is_active': 1}
 
-        self.assertItemsEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
 
     def test_truncate_data(self):
-        # Testing to see if the data set will be removed completely.
+        """
+        Testing to see if the data set will be removed completely.
+        """
         DataConnector(self.source).insert_data(self.table, self.records)
         DataConnector(self.source).truncate_data(self.table)
         given_result = DataConnector(self.source).select_data("all_columns", self.table)
@@ -80,7 +101,9 @@ class DataConnectorTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_select_all_data(self):
-        # Testing to see if the full data set will be selected correctly.
+        """
+        Testing to see if the full data set will be selected correctly.
+        """
         records = [1, 2]
         DataConnector(self.source).insert_data(self.table, records)
         given_result = DataConnector(self.source).select_data("all_columns", self.table, "user_id = 2")
@@ -96,7 +119,9 @@ class DataConnectorTests(unittest.TestCase):
     #     self.assertEquals(given_result, expected_result)
 
     def test_select_multiple_column_data(self):
-        # Testing to see if the data set will be selected correctly.
+        """
+        Testing to see if the data set will be selected correctly.
+        """
         DataConnector(self.source).insert_data(self.table, self.records)
         given_result = DataConnector(self.source).select_data("first_name, last_name", self.table, "user_id = 1")
         expected_result = [{'first_name': 'Bob', 'last_name': 'Richards'}]
@@ -104,7 +129,9 @@ class DataConnectorTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_select_single_column_data(self):
-        # Testing to see if the data set will be selected correctly.
+        """
+        Testing to see if the data set will be selected correctly.
+        """
         DataConnector(self.source).insert_data(self.table, self.records)
         given_result = DataConnector(self.source).select_data("first_name", self.table, "user_id = 1")
         expected_result = [{'first_name': 'Bob'}]
@@ -112,10 +139,12 @@ class DataConnectorTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_select_null_column_data(self):
-        # Testing to see if the data set that has a null in it will be selected correctly.
+        """
+        Testing to see if the data set that has a null in it will be selected correctly.
+        """
         records = [1, 4]
         DataConnector(self.source).insert_data(self.table, records)
         given_result = DataConnector(self.source).select_data("first_name", self.table, "user_id IN (1, 4)")
-        expected_result = [{'first_name': 'Bob'}, {'first_name': ''}]
+        expected_result = [{'first_name': 'Bob'}, {'first_name': 'Thomas'}]
 
-        self.assertItemsEqual(given_result, expected_result)
\ No newline at end of file
+        self.assertCountEqual(given_result, expected_result)
\ No newline at end of file
