@@ -1,11 +1,15 @@
+"""
+Testing the SettingsManager module.
+"""
+
 __author__ = 'ameadows'
 
 import unittest
 from collections import OrderedDict
 import inspect
-
 import re
 import os
+
 import appdirs
 
 from etltest.utilities.settings import etltest_config
@@ -13,8 +17,15 @@ from etltest.utilities.settings_manager import SettingsManager
 
 
 class SettingsManagerTests(unittest.TestCase):
-
+    """
+    Module for testing SettingsManager.
+    """
     def setUp(self):
+        """
+            Setting up tests by running the first run setup and setting specific variables
+            based on the config file.
+        """
+
         SettingsManager().first_run_test()
         self.app_name = etltest_config['app_name']
         self.app_author = etltest_config['app_author']
@@ -31,27 +42,51 @@ class SettingsManagerTests(unittest.TestCase):
         self.maxDiff = None
 
     def test_data_dir_exists(self):
+        """
+        Testing to see if the data directory exists after the first run setup.
+        """
         assert os.path.exists(self.data_dir)
 
     def test_log_dir_exists(self):
+        """
+        Testing to see if the log directory exists after the first run setup.
+        """
         assert os.path.exists(self.log_dir)
 
     def test_settings_file_exists(self):
+        """
+        Testing to see if the settings file exists after the first run setup.
+        """
         assert os.path.isfile(self.settings_file)
 
     def test_tools_file_exists(self):
+        """
+        Testing to see if the tools file exists after the first run setup.
+        """
         assert os.path.isfile(self.tools_file)
 
     def test_data_samples_exists(self):
+        """
+        Testing to see if the data sample files exists after the first run setup.
+        """
         assert os.path.isdir(self.data_location)
 
     def test_tests_dir_exists(self):
+        """
+        Testing to see if the test directory exists after the first run setup.
+        """
         assert os.path.isdir(self.tests_location)
 
     def test_output_dir_exists(self):
+        """
+        Testing if the output directory exists after running the settings manager first run setup.
+        """
         assert os.path.isdir(self.output_location)
 
     def test_get_config_settings(self):
+        """
+        Testing to see if the configuration settings are valid.
+        """
         given_result = SettingsManager().get_settings()
         expected_result = OrderedDict([('Locations', OrderedDict([('__name__', 'Locations'),
                                        ('tests', '${ETL_TEST_ROOT}/Documents/etlTest/tests'), ('data'
@@ -60,43 +95,65 @@ class SettingsManagerTests(unittest.TestCase):
                                        OrderedDict([('__name__', 'Results'), ('verbose',
                                        'True'), ('failurerate', '10'), ('reporttype', 'Normal')]))])
 
-        self.assertEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
 
     def test_get_connections(self):
+        """
+        Testing to ensure that the data source connections match from the configuration file.
+        :return:
+        """
         given_result = SettingsManager().get_connections()
         expected_result = OrderedDict([('etlUnitTest', OrderedDict([('__name__', 'etlUnitTest'),
                                                         ('hostname', '127.0.0.1'), ('username', 'root')
                                                         , ('password', ''), ('port', '3306'), ('type', 'mysql')
                                                         , ('dbname', 'etlUnitTest')]))])
 
-        self.assertEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
 
     def test_get_tools(self):
+        """
+        Testing to ensure that the tool configuration settings match the tool configuration file.
+        """
         given_result = list(SettingsManager().get_tools())
-        expected_result = [{'PDI': {'code_path': '${ETL_TEST_ROOT}/etltest/samples/etl/', 'script_types': [{'script':
-                                                                                                                'kitchen.sh', 'type': 'job'}, {'script': 'pan.sh', 'type': 'trans'}], 'port': None, 'password': None, 'private_key': '~/.ssh/id_rsa', 'process_param': '/file:', 'user_name': None, 'host_name': 'localhost', 'logging_filename_format': '${name}_%Y-%m-%d', 'tool_path': '${TOOL_PATH}', 'params': '/level: Detailed'}}]
+        expected_result = [{'PDI': {'code_path': '${ETL_TEST_ROOT}/etltest/samples/etl', 'script_types':
+                            [{'script': 'kitchen.sh', 'type': 'job'}, {'script': 'pan.sh', 'type': 'trans'}],
+                            'port': None, 'password': None, 'private_key': '~/.ssh/id_rsa', 'process_param': '/file:',
+                            'user_name': None, 'host_name': 'localhost', 'logging_filename_format': '${name}_%Y-%m-%d',
+                            'tool_path': '${TOOL_PATH}', 'params': '/level: Detailed'}}]
 
-        self.assertItemsEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
 
     def test_get_tool(self):
+        """
+        Testing to ensure that etlTest gets only one Tool from the tool configuration file.
+        """
         given_result = list(SettingsManager().get_tool('PDI'))
         expected_result = ['host_name', 'user_name', 'password', 'port', 'private_key', 'tool_path', 'script_types',
                            'params', 'process_param', 'code_path', 'logging_filename_format']
-        self.assertItemsEqual(given_result, expected_result)
+        self.assertCountEqual(given_result, expected_result)
 
     def test_find_single_setting(self):
+        """
+        Testing to ensure that a single setting is retrieved.
+        """
         given_result = SettingsManager().find_setting('Locations', 'tests')
         expected_result = os.environ.get('ETL_TEST_ROOT') + "/Documents/etlTest/tests"
 
         self.assertEqual(given_result, expected_result)
 
     def test_fail_find_single_setting(self):
+        """
+        Testing that a setting that doesn't exist returns an error message.
+        """
         given_result = SettingsManager().find_setting('Location', 'tests')
         expected_result = 'Setting does not exist or something went wrong.'
 
         self.assertEqual(given_result, expected_result)
 
     def test_get_file_location(self):
+        """
+        Testing that get_file_location returns back the root directory for etlTest.
+        """
         given_result = SettingsManager().get_file_location()
         expected_result = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
         expected_result = re.sub('/etltest/test/utilities', '', expected_result)
@@ -104,6 +161,9 @@ class SettingsManagerTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_system_variable_replace(self):
+        """
+        Testing that variables in a setting value are replaced with their proper value.
+        """
         parameter = "${ETL_TEST_ROOT}/this_is_a_test/file.txt"
         given_result = SettingsManager().system_variable_replace(parameter)
         expected_result = str(os.environ.get('ETL_TEST_ROOT')) + "/this_is_a_test/file.txt"
@@ -111,15 +171,21 @@ class SettingsManagerTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_bad_system_variable_replace(self):
+        """
+        Testing that if a variable being replaced doesn't exist, an error is thrown.
+        """
         parameter = "${ETL_TEST_TOOT}/this_is_a_test/file.txt"
         expected_result = "The system variable either does not exist or has a bad value. System variable: ETL_TEST_TOOT"
 
         with self.assertRaises(Exception) as raises:
             SettingsManager().system_variable_replace(parameter)
 
-        self.assertEqual(raises.exception.message, expected_result)
+        self.assertEqual(str(raises.exception), expected_result)
 
     def test_copy_settings_file(self):
+        """
+        Testing that files are being copied properly with the copy_settings_file.
+        """
         SettingsManager().copy_settings_file('copy.test')
         given_result = os.path.isfile(self.copy_file)
         expected_result = True
@@ -127,6 +193,9 @@ class SettingsManagerTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_no_system_variable_replace(self):
+        """
+        Testing that even if a variable is passed and it doesn't exist, it gets ignored.
+        """
         parameter = "no_parameter/this_is_a_test/file.txt"
         given_result = SettingsManager().system_variable_replace(parameter)
         expected_result = "no_parameter/this_is_a_test/file.txt"
@@ -134,7 +203,9 @@ class SettingsManagerTests(unittest.TestCase):
         self.assertEqual(given_result, expected_result)
 
     def test_copy_files(self):
-
+        """
+        Verifying that needed files are moved over.
+        """
         given_result = os.path.isfile(os.path.join(self.data_location, "etlUnitTest/users.yml"))
         expected_result = True
 
