@@ -12,7 +12,7 @@ import pprint
 import os
 import yaml
 
-from settings_manager import SettingsManager
+from .settings_manager import SettingsManager
 
 
 
@@ -48,10 +48,10 @@ for the_path in settings_fs_locs:
     try:
         with open(the_path, 'r') as f:
             prop_list = yaml.load(f.read())
-            for key, value in prop_list.items():
+            for key, value in list(prop_list.items()):
                 etltest_config[key] = value
 
-            settings_log.debug(u"Settings loaded from {0:s}, {1:s}".format(the_path, etltest_config))
+            settings_log.debug("Settings loaded from {0:s}, {1:s}".format(the_path, etltest_config))
             settings_loaded = True
             break
     except (OSError, IOError) as e:
